@@ -9,6 +9,7 @@
 #include "DiscoverBackendsFactory.h"
 #include "DiscoverDeclarativePlugin.h"
 #include "FeaturedModel.h"
+#include "OdrsAppsModel.h"
 #include "PaginateModel.h"
 #include "UnityLauncher.h"
 #include <Transaction/TransactionModel.h>
@@ -105,6 +106,7 @@ DiscoverObject::DiscoverObject(CompactMode mode, const QVariantMap &initialPrope
     qmlRegisterType<UnityLauncher>("org.kde.discover.app", 1, 0, "UnityLauncher");
     qmlRegisterType<PaginateModel>("org.kde.discover.app", 1, 0, "PaginateModel");
     qmlRegisterType<FeaturedModel>("org.kde.discover.app", 1, 0, "FeaturedModel");
+    qmlRegisterType<OdrsAppsModel>("org.kde.discover.app", 1, 0, "OdrsAppsModel");
     qmlRegisterType<PowerManagementInterface>("org.kde.discover.app", 1, 0, "PowerManagementInterface");
     qmlRegisterType<OurSortFilterProxyModel>("org.kde.discover.app", 1, 0, "QSortFilterProxyModel");
 #ifdef WITH_FEEDBACK
@@ -112,8 +114,9 @@ DiscoverObject::DiscoverObject(CompactMode mode, const QVariantMap &initialPrope
         return new PlasmaUserFeedback(KSharedConfig::openConfig(QStringLiteral("PlasmaUserFeedback"), KConfig::NoGlobals));
     });
 #endif
-    qmlRegisterSingletonType<DiscoverSettings>("org.kde.discover.app", 1, 0, "DiscoverSettings", [](QQmlEngine *, QJSEngine *) -> QObject * {
+    qmlRegisterSingletonType<DiscoverSettings>("org.kde.discover.app", 1, 0, "DiscoverSettings", [](QQmlEngine *engine, QJSEngine *) -> QObject * {
         auto r = new DiscoverSettings;
+        r->setParent(engine);
         connect(r, &DiscoverSettings::installedPageSortingChanged, r, &DiscoverSettings::save);
         connect(r, &DiscoverSettings::appsListPageSortingChanged, r, &DiscoverSettings::save);
         return r;
@@ -278,8 +281,8 @@ void DiscoverObject::openCategory(const QString &category)
 void DiscoverObject::openLocalPackage(const QUrl &localfile)
 {
     if (!QFile::exists(localfile.toLocalFile())) {
-        // showPassiveNotification(i18n("Trying to open unexisting file '%1'", localfile.toString()));
-        qCWarning(DISCOVER_LOG) << "Trying to open unexisting file" << localfile;
+        showPassiveNotification(i18n("Trying to open inexisting file '%1'", localfile.toString()));
+        openMode(QStringLiteral("Browsing"));
         return;
     }
     showLoadingPage();
