@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef TRANSACTIONMODEL_H
-#define TRANSACTIONMODEL_H
+#pragma once
 
 #include <QAbstractListModel>
 
@@ -18,6 +17,7 @@ class DISCOVERCOMMON_EXPORT TransactionModel : public QAbstractListModel
     Q_OBJECT
     Q_PROPERTY(int progress READ progress NOTIFY progressChanged)
     Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
+    Q_PROPERTY(QString mainTransactionText READ mainTransactionText NOTIFY mainTransactionTextChanged)
 public:
     enum Roles {
         TransactionRoleRole = Qt::UserRole,
@@ -54,6 +54,8 @@ public:
         return m_transactions;
     }
 
+    QString mainTransactionText() const;
+
 private:
     QVector<Transaction *> m_transactions;
 
@@ -65,9 +67,8 @@ Q_SIGNALS:
     void countChanged();
     void progressChanged();
     void proceedRequest(Transaction *transaction, const QString &title, const QString &description);
+    void mainTransactionTextChanged();
 
 private Q_SLOTS:
     void transactionChanged(int role);
 };
-
-#endif // TRANSACTIONMODEL_H
