@@ -4,11 +4,11 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef APPSTREAMUTILS_H
-#define APPSTREAMUTILS_H
+#pragma once
 
 #include <AppStreamQt/component.h>
 #include <AppStreamQt/image.h>
+#include <AppStreamQt/pool.h>
 #include <QColor>
 #include <QList>
 #include <QUrl>
@@ -37,6 +37,6 @@ Q_DECL_EXPORT QString contentRatingText(const AppStream::Component &appdata);
 Q_DECL_EXPORT QString contentRatingDescription(const AppStream::Component &appdata);
 Q_DECL_EXPORT AbstractResource::ContentIntensity contentRatingIntensity(const AppStream::Component &appdata);
 Q_DECL_EXPORT uint contentRatingMinimumAge(const AppStream::Component &appdata);
-}
 
-#endif
+Q_DECL_EXPORT QList<AppStream::Component> componentsByCategories(AppStream::Pool *pool, Category *cat, AppStream::Bundle::Kind kind);
+}
