@@ -25,6 +25,7 @@
 #include <AppStreamQt/metadata.h>
 #include <AppStreamQt/pool.h>
 #include <AppStreamQt/release.h>
+#include <AppStreamQt/version.h>
 
 #include <KAboutData>
 #include <KConfigGroup>
@@ -48,6 +49,7 @@
 #include <QRegularExpression>
 #include <glib.h>
 
+#include <Category/Category.h>
 #include <optional>
 #include <set>
 #include <sys/stat.h>
@@ -93,10 +95,12 @@ public:
         return m_remote && !flatpak_remote_get_disabled(m_remote);
     }
 
-    QString appstreamIconsDir() const {
+    QString appstreamIconsDir() const
+    {
         return m_appstreamIconsDir;
     }
-    QString appstreamDir() const {
+    QString appstreamDir() const
+    {
         Q_ASSERT(m_remote);
         g_autoptr(GFile) appstreamDir = flatpak_remote_get_appstream_dir(m_remote, nullptr);
         if (!appstreamDir) {
@@ -154,19 +158,11 @@ public:
 
     QList<AppStream::Component> componentsByName(const QString &name)
     {
-        QList<AppStream::Component> comps;
-        auto findComponents = [&](const QString &name) {
-            comps = m_pool->componentsById(name);
-            if (!comps.isEmpty())
-                return;
+        QList<AppStream::Component> comps = m_pool->componentsById(name);
+        if (!comps.isEmpty())
+            return comps;
 
-            comps = m_pool->componentsByProvided(AppStream::Provided::KindId, name);
-        };
-
-        findComponents(name);
-        if (comps.isEmpty()) {
-            findComponents(name + QLatin1String(".desktop"));
-        }
+        comps = m_pool->componentsByProvided(AppStream::Provided::KindId, name);
         return comps;
     }
 
@@ -273,6 +269,7 @@ FlatpakBackend::FlatpakBackend(QObject *parent)
     , m_updater(new StandardBackendUpdater(this))
     , m_reviews(AppStreamIntegration::global()->reviews())
     , m_cancellable(g_cancellable_new())
+    , m_checkForUpdatesTimer(new QTimer(this))
 {
     g_autoptr(GError) error = nullptr;
 
@@ -294,6 +291,10 @@ FlatpakBackend::FlatpakBackend(QObject *parent)
                                      }));
     });
 
+    m_checkForUpdatesTimer->setInterval(1000);
+    m_checkForUpdatesTimer->setSingleShot(true);
+    connect(m_checkForUpdatesTimer, &QTimer::timeout, this, &FlatpakBackend::checkForUpdates);
+
     /* Override the umask to 022 to make it possible to share files between
      * the plasma-discover process and flatpak system helper process.
      *
@@ -445,10 +446,6 @@ FlatpakResource *FlatpakBackend::getAppForInstalledRef(FlatpakInstallation *inst
         if (ret) {
             return ret;
         }
-        ret = source->m_resources.value(idForInstalledRef(ref, QStringLiteral(".desktop")));
-        if (ret) {
-            return ret;
-        }
     }
 
     const QLatin1String name(flatpak_ref_get_name(FLATPAK_REF(ref)));
@@ -874,7 +871,6 @@ void FlatpakBackend::addAppFromFlatpakRef(const QUrl &url, ResultsStream *stream
         Q_EMIT stream->resourcesFound({resource});
         stream->finish();
     }
-
 }
 
 void FlatpakBackend::addSourceFromFlatpakRepo(const QUrl &url, ResultsStream *stream)
@@ -971,9 +967,13 @@ void FlatpakBackend::loadRemote(FlatpakInstallation *installation, FlatpakRemote
 
     g_autofree char *path_str = g_file_get_path(fileTimestamp);
     QFileInfo fileInfo(QFile::encodeName(path_str));
-    // Refresh appstream metadata in case they have never been refreshed or the cache is older than 6 hours
-    if (!fileInfo.exists() || fileInfo.lastModified().toUTC().secsTo(QDateTime::currentDateTimeUtc()) > 21600) {
-        checkForUpdates(installation, remote);
+    if (!fileInfo.exists()) {
+        checkForRemoteUpdates(installation, remote);
+
+        // Refresh appstream metadata in case they have never been refreshed or the cache is older than 6 hours
+        if (fileInfo.lastModified().toUTC().secsTo(QDateTime::currentDateTimeUtc()) > 21600) {
+            connect(this, &FlatpakBackend::initialized, m_checkForUpdatesTimer, qOverload<>(&QTimer::start));
+        }
     } else {
         auto source = integrateRemote(installation, remote);
         Q_ASSERT(findSource(installation, flatpak_remote_get_name(remote)) == source);
@@ -1139,7 +1139,7 @@ bool FlatpakBackend::setupFlatpakInstallations(GError **error)
         qDebug() << "running flatpak backend on test mode" << path;
         g_autoptr(GFile) file = g_file_new_for_path(QFile::encodeName(path).constData());
         m_installations << flatpak_installation_new_for_path(file, true, m_cancellable, error);
-        return true;
+        return m_installations.constLast() != nullptr;
     }
 
     g_autoptr(GPtrArray) installations = flatpak_get_system_installations(m_cancellable, error);
@@ -1428,7 +1428,7 @@ ResultsStream *FlatpakBackend::search(const AbstractResourcesBackend::Filters &f
                     return ret;
                 }
 
-                for (auto installation : installations) {
+                for (auto installation : std::as_const(installations)) {
                     g_autoptr(GError) localError = nullptr;
                     g_autoptr(GPtrArray) refs = flatpak_installation_list_installed_refs_for_update(installation, cancellable, &localError);
                     if (!refs) {
@@ -1441,6 +1441,10 @@ ResultsStream *FlatpakBackend::search(const AbstractResourcesBackend::Filters &f
                         break;
                     }
 
+                    if (refs->len == 0) {
+                        continue;
+                    }
+
                     auto &current = ret[installation];
                     current.reserve(refs->len);
                     for (uint i = 0; i < refs->len; i++) {
@@ -1509,7 +1513,14 @@ ResultsStream *FlatpakBackend::search(const AbstractResourcesBackend::Filters &f
         for (const auto &source : qAsConst(m_flatpakSources)) {
             QList<FlatpakResource *> resources;
             if (source->m_pool) {
-                resources = kTransform<QList<FlatpakResource *>>(source->m_pool->search(filter.search), [this, &source](const auto &comp) {
+                const auto a = !filter.search.isEmpty() ? source->m_pool->search(filter.search)
+#if ASQ_MAJOR_VERSION >= 0 && ASQ_MINOR_VERSION >= 15 && ASQ_MICRO_VERSION >= 6
+                    : filter.category                   ? AppStreamUtils::componentsByCategories(source->m_pool,
+                                                                                                 filter.category,
+                                                                                                 AppStream::Bundle::KindFlatpak)
+#endif
+                                                        : source->m_pool->components();
+                resources = kTransform<QList<FlatpakResource *>>(a, [this, &source](const auto &comp) {
                     return resourceForComponent(comp, source);
                 });
             } else {
@@ -1776,12 +1787,12 @@ void FlatpakBackend::checkForUpdates()
         if (source->remote()) {
             Q_ASSERT(!m_refreshAppstreamMetadataJobs.contains(source->remote()));
             m_refreshAppstreamMetadataJobs.insert(source->remote());
-            checkForUpdates(source->installation(), source->remote());
+            checkForRemoteUpdates(source->installation(), source->remote());
         }
     }
 }
 
-void FlatpakBackend::checkForUpdates(FlatpakInstallation *installation, FlatpakRemote *remote)
+void FlatpakBackend::checkForRemoteUpdates(FlatpakInstallation *installation, FlatpakRemote *remote)
 {
     Q_ASSERT(remote);
     const bool needsIntegration = m_refreshAppstreamMetadataJobs.contains(remote);
@@ -1809,14 +1820,14 @@ QString FlatpakBackend::displayName() const
     return QStringLiteral("Flatpak");
 }
 
-HelpfulError *FlatpakBackend::explainDysfunction() const
+InlineMessage *FlatpakBackend::explainDysfunction() const
 {
     if (m_flatpakSources.isEmpty()) {
-        return new HelpfulError(QStringLiteral("emblem-error"), i18n("There are no Flatpak sources."), m_sources->actions());
+        return new InlineMessage(InlineMessage::Error, QStringLiteral("emblem-error"), i18n("There are no Flatpak sources."), m_sources->actions());
     }
     for (const auto &source : m_flatpakSources) {
         if (source->m_pool && !source->m_pool->lastError().isEmpty()) {
-            return new HelpfulError(QStringLiteral("emblem-error"), i18n("Failed to load \"%1\" source", source->name()));
+            return new InlineMessage(InlineMessage::Error, QStringLiteral("emblem-error"), i18n("Failed to load \"%1\" source", source->name()));
         }
     }
     return AbstractResourcesBackend::explainDysfunction();
