@@ -35,6 +35,8 @@ public:
     FlatpakTest(QObject *parent = nullptr)
         : QObject(parent)
     {
+        QDir(QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QLatin1String("/discover-flatpak-test")).removeRecursively();
+
         QStandardPaths::setTestModeEnabled(true);
         qputenv("FLATPAK_TEST_MODE", "ON");
         m_model = new ResourcesModel(QStringLiteral("flatpak-backend"), this);
@@ -44,8 +46,6 @@ public:
 private Q_SLOTS:
     void initTestCase()
     {
-        QDir(QStandardPaths::writableLocation(QStandardPaths::TempLocation) + QLatin1String("/discover-flatpak-test")).removeRecursively();
-
         QVERIFY(m_appBackend);
         while (m_appBackend->isFetching()) {
             QSignalSpy spy(m_appBackend, &AbstractResourcesBackend::fetchingChanged);
@@ -83,16 +83,16 @@ private Q_SLOTS:
     void testInstallApp()
     {
         AbstractResourcesBackend::Filters f;
-        f.resourceUrl = QUrl(QStringLiteral("appstream://com.github.rssguard.desktop"));
+        f.resourceUrl = QUrl(QStringLiteral("appstream://dosbox.desktop"));
         const auto res = getResources(m_appBackend->search(f));
         QCOMPARE(res.count(), 1);
 
-        const auto resRssguard = res.constFirst();
-        QCOMPARE(resRssguard->state(), AbstractResource::None);
-        QCOMPARE(waitTransaction(m_appBackend->installApplication(resRssguard)), Transaction::DoneStatus);
-        QCOMPARE(resRssguard->state(), AbstractResource::Installed);
-        QCOMPARE(waitTransaction(m_appBackend->removeApplication(resRssguard)), Transaction::DoneStatus);
-        QCOMPARE(resRssguard->state(), AbstractResource::None);
+        const auto ourResource = res.constFirst();
+        QCOMPARE(ourResource->state(), AbstractResource::None);
+        QCOMPARE(waitTransaction(m_appBackend->installApplication(ourResource)), Transaction::DoneStatus);
+        QCOMPARE(ourResource->state(), AbstractResource::Installed);
+        QCOMPARE(waitTransaction(m_appBackend->removeApplication(ourResource)), Transaction::DoneStatus);
+        QCOMPARE(ourResource->state(), AbstractResource::None);
     }
     /*
         void testCancelInstallation()
@@ -127,12 +127,14 @@ private:
         QSignalSpy destructionSpy(t, &QObject::destroyed);
 
         Transaction::Status ret = t->status();
-        connect(TransactionModel::global(), &TransactionModel::transactionRemoved, this, [t, &ret] {
-            ret = t->status();
+        connect(TransactionModel::global(), &TransactionModel::transactionRemoved, t, [t, &ret](Transaction *trans) {
+            if (trans == t) {
+                ret = trans->status();
+            }
         });
         while (t && spyInstalled.count() == 0) {
             qDebug() << "waiting, currently" << ret << spyInstalled.count() << destructionSpy.count();
-            spyInstalled.wait(100);
+            spyInstalled.wait(1000);
         }
         Q_ASSERT(destructionSpy.count() || destructionSpy.wait());
         return ret;
@@ -164,6 +166,6 @@ private:
     AbstractResourcesBackend *m_appBackend;
 };
 
-QTEST_MAIN(FlatpakTest)
+QTEST_GUILESS_MAIN(FlatpakTest)
 
 #include "FlatpakTest.moc"
