@@ -14,6 +14,7 @@
 #include "PackageKitUpdater.h"
 #include <AppStreamQt/release.h>
 #include <AppStreamQt/utils.h>
+#include <AppStreamQt/version.h>
 #include <appstream/AppStreamIntegration.h>
 #include <appstream/AppStreamUtils.h>
 #include <appstream/OdrsReviewsBackend.h>
@@ -24,6 +25,7 @@
 #include <QDebug>
 #include <QFileSystemWatcher>
 #include <QFutureWatcher>
+#include <QHash>
 #include <QMimeDatabase>
 #include <QProcess>
 #include <QStandardPaths>
@@ -40,9 +42,30 @@
 #include "config-paths.h"
 #include "libdiscover_backend_debug.h"
 #include "utils.h"
+#include <Category/Category.h>
 
 DISCOVER_BACKEND_PLUGIN(PackageKitBackend)
 
+bool operator==(const PackageOrAppId &a, const PackageOrAppId &b)
+{
+    return a.isPackageName == b.isPackageName && a.id == b.id;
+}
+
+uint qHash(const PackageOrAppId &id, uint seed)
+{
+    return qHash(id.id, seed) ^ qHash(id.isPackageName, seed);
+}
+
+PackageOrAppId makeAppId(const QString &id)
+{
+    return {id, false};
+}
+
+PackageOrAppId makePackageId(const QString &id)
+{
+    return {id, true};
+}
+
 template<typename T, typename W>
 static void setWhenAvailable(const QDBusPendingReply<T> &pending, W func, QObject *parent)
 {
@@ -242,11 +265,12 @@ void PackageKitBackend::reloadPackageList()
                     }
                     if (r.timestampEol() < QDateTime::currentDateTime()) {
                         const QString releaseDate = QLocale().toString(r.timestampEol());
-                        Q_EMIT inlineMessage(InlineMessageType::Warning,
-                                             QStringLiteral("dialog-warning"),
-                                             i18nc("%1 is the date as formatted by the locale",
-                                                   "Your operating system ended support on %1. Consider upgrading to a supported version.",
-                                                   releaseDate));
+                        Q_EMIT inlineMessageChanged(
+                            QSharedPointer<InlineMessage>::create(InlineMessage::Warning,
+                                                                  QStringLiteral("dialog-warning"),
+                                                                  i18nc("%1 is the date as formatted by the locale",
+                                                                        "Your operating system ended support on %1. Consider upgrading to a supported version.",
+                                                                        releaseDate)));
                     }
                 }
             }
@@ -261,7 +285,7 @@ AppPackageKitResource *PackageKitBackend::addComponent(const AppStream::Componen
     const QStringList pkgNames = component.packageNames();
     Q_ASSERT(!pkgNames.isEmpty());
 
-    auto &resPos = m_packages.packages[component.id()];
+    auto &resPos = m_packages.packages[makeAppId(component.id())];
     AppPackageKitResource *res = qobject_cast<AppPackageKitResource *>(resPos);
     if (!res) {
         res = new AppPackageKitResource(component, pkgNames.at(0), this);
@@ -356,12 +380,12 @@ void PackageKitBackend::includePackagesToAdd()
 
     acquireFetching(true);
     for (PackageKitResource *res : qAsConst(m_packagesToAdd)) {
-        m_packages.packages[res->packageName()] = res;
+        m_packages.packages[makePackageId(res->packageName())] = res;
     }
     for (PackageKitResource *res : qAsConst(m_packagesToDelete)) {
         const auto pkgs = m_packages.packageToApp.value(res->packageName(), {res->packageName()});
         for (const auto &pkg : pkgs) {
-            auto res = m_packages.packages.take(pkg);
+            auto res = m_packages.packages.take(makePackageId(pkg));
             if (res) {
                 if (AppPackageKitResource *ares = qobject_cast<AppPackageKitResource *>(res)) {
                     const auto extends = res->extends();
@@ -398,20 +422,42 @@ void PackageKitBackend::packageDetails(const PackageKit::Details &details)
 
 QSet<AbstractResource *> PackageKitBackend::resourcesByPackageName(const QString &name) const
 {
-    return resourcesByPackageNames<QSet<AbstractResource *>>({name});
+    return resourcesByPackageNames<QSet<AbstractResource *>>(QStringList{name});
 }
 
-template<typename T>
-T PackageKitBackend::resourcesByPackageNames(const QStringList &pkgnames) const
+template<typename T, typename W>
+T PackageKitBackend::resourcesByAppNames(const W &appNames) const
+{
+    T ret;
+    ret.reserve(appNames.size());
+    for (const QString &name : appNames) {
+        AbstractResource *res = m_packages.packages.value(makeAppId(name));
+        if (res) {
+            ret += res;
+        }
+    }
+    return ret;
+}
+
+template<typename T, typename W>
+T PackageKitBackend::resourcesByPackageNames(const W &pkgnames) const
 {
     T ret;
     ret.reserve(pkgnames.size());
-    for (const QString &name : pkgnames) {
-        const QStringList names = m_packages.packageToApp.value(name, QStringList(name));
-        for (const QString &name : names) {
-            AbstractResource *res = m_packages.packages.value(name);
-            if (res)
+    for (const QString &pkg_name : pkgnames) {
+        const QStringList app_names = m_packages.packageToApp.value(pkg_name, QStringList());
+        if (app_names.isEmpty()) {
+            AbstractResource *res = m_packages.packages.value(makePackageId(pkg_name));
+            if (res) {
                 ret += res;
+            }
+        } else {
+            for (const QString &app_id : app_names) {
+                AbstractResource *res = m_packages.packages.value(makeAppId(app_id));
+                if (res) {
+                    ret += res;
+                }
+            }
         }
     }
     return ret;
@@ -442,7 +488,11 @@ void PackageKitBackend::checkForUpdates()
 QList<AppStream::Component> PackageKitBackend::componentsById(const QString &id) const
 {
     Q_ASSERT(m_appstreamInitialized);
-    return m_appdata->componentsById(id);
+    auto comps = m_appdata->componentsById(id);
+    if (comps.isEmpty()) {
+        comps = m_appdata->componentsByProvided(AppStream::Provided::KindId, id);
+    }
+    return comps;
 }
 
 static const auto needsResolveFilter = [](AbstractResource *res) {
@@ -473,6 +523,7 @@ public:
         if (res.isEmpty())
             return;
 
+        Q_ASSERT(res.size() == QSet(res.constBegin(), res.constEnd()).size());
         const auto toResolve = kFilter<QVector<AbstractResource *>>(res, needsResolveFilter);
         if (!toResolve.isEmpty())
             backend->resolvePackages(kTransform<QStringList>(toResolve, [](AbstractResource *res) {
@@ -543,7 +594,7 @@ ResultsStream *PackageKitBackend::search(const AbstractResourcesBackend::Filters
         };
         runWhenInitialized(f, stream);
         return stream;
-    } else if (filter.search.isEmpty()) {
+    } else if (filter.search.isEmpty() && !filter.category) {
         auto stream = new PKResultsStream(this, QStringLiteral("PackageKitStream-all"));
         auto f = [this, filter, stream] {
             auto resources = kFilter<QVector<AbstractResource *>>(m_packages.packages, [](AbstractResource *res) {
@@ -558,15 +609,20 @@ ResultsStream *PackageKitBackend::search(const AbstractResourcesBackend::Filters
     } else {
         auto stream = new PKResultsStream(this, QStringLiteral("PackageKitStream-search"));
         const auto f = [this, stream, filter]() {
-            const QList<AppStream::Component> components = m_appdata->search(filter.search);
-            const QStringList ids = kTransform<QStringList>(components, [](const AppStream::Component &comp) {
+            const auto components = !filter.search.isEmpty() ? m_appdata->search(filter.search)
+#if ASQ_MAJOR_VERSION >= 0 && ASQ_MINOR_VERSION >= 15 && ASQ_MICRO_VERSION >= 6
+                                  : filter.category          ? AppStreamUtils::componentsByCategories(m_appdata.get(),
+                                                                                                      filter.category,
+                                                                                                      AppStream::Bundle::KindUnknown)
+#endif
+                                                             : m_appdata->components();
+            const QSet<QString> ids = kTransform<QSet<QString>>(components, [](const AppStream::Component &comp) {
                 return comp.id();
             });
             if (!ids.isEmpty()) {
-                const auto resources =
-                    kFilter<QVector<AbstractResource *>>(resourcesByPackageNames<QVector<AbstractResource *>>(ids), [](AbstractResource *res) {
-                        return !qobject_cast<PackageKitResource *>(res)->extendsItself();
-                    });
+                const auto resources = kFilter<QVector<AbstractResource *>>(resourcesByAppNames<QVector<AbstractResource *>>(ids), [](AbstractResource *res) {
+                    return !qobject_cast<PackageKitResource *>(res)->extendsItself();
+                });
                 stream->setResources(resources);
             }
             stream->finish();
@@ -598,52 +654,26 @@ PKResultsStream *PackageKitBackend::findResourceByPackageName(const QUrl &url)
             return new PKResultsStream(this, QStringLiteral("PackageKitStream-localpkg"), {new LocalFilePKResource(url, this)});
         }
     } else if (url.scheme() == QLatin1String("appstream")) {
-        static const QMap<QString, QString> deprecatedAppstreamIds = {
-            {QStringLiteral("org.kde.krita.desktop"), QStringLiteral("krita.desktop")},
-            {QStringLiteral("org.kde.digikam.desktop"), QStringLiteral("digikam.desktop")},
-            {QStringLiteral("org.kde.ktorrent.desktop"), QStringLiteral("ktorrent.desktop")},
-            {QStringLiteral("org.kde.gcompris.desktop"), QStringLiteral("gcompris.desktop")},
-            {QStringLiteral("org.kde.kmymoney.desktop"), QStringLiteral("kmymoney.desktop")},
-            {QStringLiteral("org.kde.kolourpaint.desktop"), QStringLiteral("kolourpaint.desktop")},
-            {QStringLiteral("org.blender.blender.desktop"), QStringLiteral("blender.desktop")},
-        };
-
         const auto appstreamIds = AppStreamUtils::appstreamIds(url);
         if (appstreamIds.isEmpty())
             Q_EMIT passiveMessage(i18n("Malformed appstream url '%1'", url.toDisplayString()));
         else {
             auto stream = new PKResultsStream(this, QStringLiteral("PackageKitStream-appstream-url"));
             const auto f = [this, appstreamIds, stream]() {
-                AbstractResource *pkg = nullptr;
-
-                QStringList allAppStreamIds = appstreamIds;
-                {
-                    auto it = deprecatedAppstreamIds.constFind(appstreamIds.first());
-                    if (it != deprecatedAppstreamIds.constEnd()) {
-                        allAppStreamIds << *it;
+                auto toSend = QSet<AbstractResource *>();
+                toSend.reserve(appstreamIds.size());
+                for (const auto &appstreamId : appstreamIds) {
+                    const auto comps = componentsById(appstreamId);
+                    if (comps.isEmpty()) {
+                        continue;
+                    }
+                    auto resources = resourcesByComponents<QVector<AbstractResource *>>(comps);
+                    for (const auto &r : resources) {
+                        toSend.insert(r);
                     }
                 }
-
-                for (auto it = m_packages.packages.constBegin(), itEnd = m_packages.packages.constEnd(); it != itEnd; ++it) {
-                    const bool matches = kContains(allAppStreamIds, [&it](const QString &id) {
-                        static const QLatin1String desktopPostfix(".desktop");
-                        return it.key().compare(id, Qt::CaseInsensitive) == 0 ||
-                            // doing (id == id.key()+".desktop") without allocating
-                            (id.size() == (desktopPostfix.size() + it.key().size()) && id.endsWith(desktopPostfix)
-                             && id.startsWith(it.key(), Qt::CaseInsensitive)) ||
-                            (it.key().size() == (desktopPostfix.size() + id.size()) && it.key().endsWith(desktopPostfix)
-                             && it.key().startsWith(id, Qt::CaseInsensitive));
-                    });
-                    if (matches) {
-                        pkg = it.value();
-                        break;
-                    }
-                }
-                if (pkg)
-                    stream->setResources({pkg});
+                stream->setResources(QVector(toSend.constBegin(), toSend.constEnd()));
                 stream->finish();
-                //         if (!pkg)
-                //             qCDebug(LIBDISCOVER_BACKEND_LOG) << "could not find" << host << deprecatedHost;
             };
             runWhenInitialized(f, stream);
             return stream;
@@ -652,6 +682,23 @@ PKResultsStream *PackageKitBackend::findResourceByPackageName(const QUrl &url)
     return new PKResultsStream(this, QStringLiteral("PackageKitStream-unknown-url"), {});
 }
 
+template<typename T>
+T PackageKitBackend::resourcesByComponents(const QList<AppStream::Component> &comps) const
+{
+    T ret;
+    ret.reserve(comps.size());
+    QSet<QString> done;
+    for (const auto &comp : comps) {
+        if (comp.packageNames().isEmpty() || done.contains(comp.id())) {
+            continue;
+        }
+        done += comp.id();
+        ret << m_packages.packages.value(makeAppId(comp.id()));
+        Q_ASSERT(ret.constLast());
+    }
+    return ret;
+}
+
 bool PackageKitBackend::hasSecurityUpdates() const
 {
     return m_hasSecurityUpdates;
@@ -858,11 +905,11 @@ int PackageKitBackend::fetchingUpdatesProgress() const
     return percentage;
 }
 
-HelpfulError *PackageKitBackend::explainDysfunction() const
+InlineMessage *PackageKitBackend::explainDysfunction() const
 {
     const auto error = m_appdata->lastError();
     if (!error.isEmpty()) {
-        return new HelpfulError(QStringLiteral("network-disconnect"), error);
+        return new InlineMessage(InlineMessage::Error, QStringLiteral("network-disconnect"), error);
     }
     return AbstractResourcesBackend::explainDysfunction();
 }
